==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/LiteralFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { LiteralFilterExpressionDescription } from "./LiteralFilterExpressionDescription";
/**
 * @hidden
 */
export let LiteralFilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LiteralFilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LiteralFilterExpressionDescriptionMetadata.a == null) {
                LiteralFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LiteralFilterExpressionDescriptionMetadata.c(LiteralFilterExpressionDescriptionMetadata.a);
            }
            if (a.j(LiteralFilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(LiteralFilterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("LiteralValue", "Unknown");
            a.item("LeaveUnquoted", "Boolean");
        }
        static d(a) {
            LiteralFilterExpressionDescriptionMetadata.b(a);
            a.aa("LiteralFilterExpression", () => new LiteralFilterExpressionDescription());
            a.z("LiteralFilterExpression", LiteralFilterExpressionDescriptionMetadata.a);
        }
    }
    LiteralFilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LiteralFilterExpressionDescriptionMetadata, 'LiteralFilterExpressionDescriptionMetadata');
    LiteralFilterExpressionDescriptionMetadata.a = null;
    return LiteralFilterExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LiteralFilterExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FilterExpressionDescriptionMetadata } from "./FilterExpressionDescriptionMetadata";
import { LiteralFilterExpressionDescription } from "./LiteralFilterExpressionDescription";
/**
 * @hidden
 */
export let LiteralFilterExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LiteralFilterExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LiteralFilterExpressionDescriptionMetadata.a == null) {
                LiteralFilterExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LiteralFilterExpressionDescriptionMetadata.c(LiteralFilterExpressionDescriptionMetadata.a);
            }
            if (a.k(LiteralFilterExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(LiteralFilterExpressionDescriptionMetadata.a);
        }
        static c(a) {
            FilterExpressionDescriptionMetadata.c(a);
            a.item("LiteralValue", "Unknown");
            a.item("LeaveUnquoted", "Boolean");
        }
        static d(a) {
            LiteralFilterExpressionDescriptionMetadata.b(a);
            a.ac("LiteralFilterExpression", () => new LiteralFilterExpressionDescription());
            a.ab("LiteralFilterExpression", LiteralFilterExpressionDescriptionMetadata.a);
        }
    }
    LiteralFilterExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LiteralFilterExpressionDescriptionMetadata, 'LiteralFilterExpressionDescriptionMetadata');
    LiteralFilterExpressionDescriptionMetadata.a = null;
    return LiteralFilterExpressionDescriptionMetadata;
})();
